/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IEjbJarDeployableMetadata.java 2950 2008-04-25 09:14:23Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.api;

import java.util.Collection;
import java.util.Map;

import javax.ejb.ApplicationException;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.deploy.api.deployable.metadata.IDeployableMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJInterceptors;

/**
 * IEjbJarDeployableMetadata.
 * @param <E> deployable type
 * @author Gael Lalire
 */
public interface IEjbJarDeployableMetadata<E extends EJBDeployable<E>> extends IDeployableMetadata<E> {

    /**
     * Add annotation metadata for a given class.
     * @param classAnnotationMetadata annotation metadata of a class.
     */
    void addEjbJarClassMetadata(final IEjbJarClassMetadata<E> classAnnotationMetadata);

    /**
     * Gets the class metadata for the given ejb-name.
     * @return class metadata or null if not found
     * @param ejbName the name of the EJB.
     */
    IEjbJarClassMetadata<E> getEjbJarClassMetadataForEjbName(final String ejbName);

    /**
     * Get class annotation metadata.
     * @param className key of the map of annotations bean.
     * @return Bean annotation metadata of a given name or null if class not
     *         found.
     */
    IEjbJarClassMetadata<E> getEjbJarClassMetadata(final String className);

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    Collection<IEjbJarClassMetadata<E>> getEjbJarClassMetadataCollection();

    /**
     * Gets the list of application exceptions defined on this ejb jar metadata.
     * @return the list of application exceptions defined on this ejb jar
     *         metadata.
     */
    Map<String, ApplicationException> getApplicationExceptions();

    /**
     * @return Map&lt;interceptor type &lt;--&gt; List of methods/class
     *         corresponding to the interceptor&gt; (interceptor classes) of
     *         default interceptors that enhancer will use.
     */
    // Map<InterceptorType, List<JClassInterceptor>> getDefaultInterceptors();
    /**
     * Sets the list of default interceptors that enhancers will use.<br>
     * These interceptors are defined by XML DD.
     * @param defaultInterceptors list of interceptors that enhancer will use.
     */
    // void setDefaultInterceptors(final Map<InterceptorType,
    // List<JClassInterceptor>> defaultInterceptors);
    /**
     * @return object representing list of default interceptor classes.
     */
    IJInterceptors getDefaultInterceptorsClasses();

    /**
     * Sets the object representing the default interceptor classes.
     * @param defaultInterceptorsClasses list of classes
     */
    void setDefaultInterceptorsClasses(final IJInterceptors defaultInterceptorsClasses);

}
